# History

## 0.0.1 (2021-05-18)

* First release on PyPI.

## 0.0.2 (2021-05-19)

* Added REST Loader routes.
* modified the .gitignore
* Added injection of MinosConfig on Handler class

=======
## 0.0.3 (2021-05-20)

* Bug Corrections

## 0.0.4 (2021-06-03)

* Documentation improvement.
* bugfix

## 0.0.5 (2021-08-25)

* Add `cors` entry to configuration.
